-- main.lua for title_page.love
-- a spot light effect on an image with a transparent background
help = require 'help'

function love.load()
	gr				= love.graphics
	sin, cos, pi	= math.sin, math.cos, math.pi
	bckgnd			= gr.newImage( "Love.jpg" )
	bw, bh			= bckgnd:getWidth(), bckgnd:getHeight()
	image			= gr.newImage( 'Star.png' ) -- transparent background
	iw, ih			= image:getWidth(), image:getHeight()

	effect			= love.graphics.newPixelEffect
		[[
		extern float x, y,d;
		vec4 effect(vec4 color, Image texture, vec2 tc, vec2 pixel_coords)
		{
			vec4 pixel	= Texel( texture, tc );
			float root	= sqrt((x-tc.x)*(x-tc.x)+(y-tc.y)*(y-tc.y))/d;
			pixel.r		= pixel.r - root;
			pixel.g		= pixel.g - root;
			pixel.b		= pixel.b - root;
			if (pixel.a > 0.0 ) { pixel.a = 1 - root; }
			return  pixel;
			}
		]]

	angle			= 0
	x, y, d			= 0.8, 0.1, 1.0	-- spot location & diameter
	cx, cy			= 0.5, 0.5		-- center of spot rotation
	r				= 0.4			-- radius of rotation
	set_effect( x, y, d )
	help.load()
	show_help		= true
	image_rotate	= false
	end

function love.update( dt )
	angle	= angle > 0  and angle - dt or 2 * pi
	x		= cx + r * sin( angle )
	y		= cy + r * cos( angle )
	set_effect( x, y, d )
	end

function love.draw()
	gr.draw( bckgnd )
	gr.setPixelEffect( effect )	-- apply effect to foreground
		if image_rotate then i_rot = angle else i_rot = 0 end
		gr.draw( image, bw/2, bh/2, i_rot, 1, 1, iw/2, ih/2)
		gr.setPixelEffect()
	if show_help then help.draw() end
	end

function set_effect( x, y, d )	-- send settings to shader
	effect:send( 'x', x )
	effect:send( 'y', y )
	effect:send( 'd', d )
	end

function love.keypressed(k)
	if k == 'escape'	then love.event.quit()			end
	if k == 'a'			then d = d - 0.1				end
	if k == 's'			then d = d + 0.1				end
	if k == 'q'			then r = r - 0.05				end
	if k == 'w'			then r = r + 0.05				end
	if k == 'i'			then show_help = not show_help	end
	if k == 'left'		then cx = cx - 0.1				end
	if k == 'right'		then cx = cx + 0.1				end
	if k == 'up'		then cy = cy - 0.1				end
	if k == 'down'		then cy = cy + 0.1				end
	if k == 'o'			then image_rotate = not image_rotate	end
	set_effect( x, y, d )
	end


